@@ -3,7 +3,10 @@ import matplotlib
 matplotlib.use('Agg')
 
 import matplotlib.pyplot as plt
+from scipy.stats import gaussian_kde
+from numpy import linspace, concatenate
 
+from config import CONFIG
 
 class Protein:
 
@@ -24,16 +27,19 @@ def save_report(report_path, in_file_name, scored_table, final_stat):
     svalues = final_stat["svalue"].values
     qvalues = final_stat["qvalue"].values
 
+    decoys = scored_table[scored_table["decoy"] == 1]["d_score"].values
+    targets = scored_table[scored_table["decoy"] == 0]["d_score"].values
+
     tops = scored_table[scored_table["peak_group_rank"] == 1]
     top_decoys = tops[tops["decoy"] == 1]["d_score"].values
     top_target = tops[tops["decoy"] == 0]["d_score"].values
 
     # thanks to lorenz blum for the plotting code below:
 
-    plt.figure(figsize=(8.27, 11.69))
+    plt.figure(figsize=(10, 20))
     plt.subplots_adjust(hspace=.5)
 
-    plt.subplot(311)
+    plt.subplot(411)
     plt.title(in_file_name + "\n\nROC")
     plt.xlabel('False Positive Rate (qvalue)')
     plt.ylabel('True Positive Rate (svalue)')
@@ -41,7 +47,7 @@ def save_report(report_path, in_file_name, scored_table, final_stat):
     plt.scatter(qvalues, svalues, s=3)
     plt.plot(qvalues, svalues)
 
-    plt.subplot(312)
+    plt.subplot(412)
     plt.title('d_score Performance')
     plt.xlabel('dscore cutoff')
     plt.ylabel('rates')
@@ -51,13 +57,51 @@ def save_report(report_path, in_file_name, scored_table, final_stat):
     plt.scatter(cutoffs, qvalues, color='r', s=3)
     plt.plot(cutoffs, qvalues, color='r', label="FPR (qvalue)")
 
-    plt.subplot(313)
-    plt.title("Top Peak Groups' d-score Distributions")
-    plt.xlabel("d_score")
-    plt.ylabel("# of groups")
-    plt.hist(
-        [top_target, top_decoys], 20, color=['w', 'r'], label=['target', 'decoy'], histtype='bar')
-    plt.legend(loc=2)
+    plt.subplot(413)
+    if (CONFIG.get("final_statistics.fdr_all_pg")):
+        plt.title("All Peak Groups' d_score Distributions")
+        plt.xlabel("d_score")
+        plt.ylabel("# of groups")
+        plt.hist(
+            [targets, decoys], 20, color=['w', 'r'], label=['target', 'decoy'], histtype='bar')
+        plt.legend(loc=2)
+    else:
+        plt.title("Top Peak Groups' d_score Distributions")
+        plt.xlabel("d_score")
+        plt.ylabel("# of groups")
+        plt.hist(
+            [top_target, top_decoys], 20, color=['w', 'r'], label=['target', 'decoy'], histtype='bar')
+        plt.legend(loc=2)
+
+    plt.subplot(414)
+    if (CONFIG.get("final_statistics.fdr_all_pg")):
+        atdensity = gaussian_kde(targets)
+        atdensity.covariance_factor = lambda : .25
+        atdensity._compute_covariance()
+        addensity = gaussian_kde(decoys)
+        addensity.covariance_factor = lambda : .25
+        addensity._compute_covariance()
+        axs = linspace(min(concatenate((targets,decoys))),max(concatenate((targets,decoys))),200)
+        plt.title("All Peak Groups' d_score Density")
+        plt.xlabel("d_score")
+        plt.ylabel("density")
+        plt.plot(axs, atdensity(axs), color='g', label='target')
+        plt.plot(axs, addensity(axs), color='r', label='decoy')
+        plt.legend(loc=2)
+    else:
+        tdensity = gaussian_kde(top_target)
+        tdensity.covariance_factor = lambda : .25
+        tdensity._compute_covariance()
+        ddensity = gaussian_kde(top_decoys)
+        ddensity.covariance_factor = lambda : .25
+        ddensity._compute_covariance()
+        xs = linspace(min(concatenate((top_target,top_decoys))),max(concatenate((top_target,top_decoys))),200)
+        plt.title("Top Peak Groups' d_score Density")
+        plt.xlabel("d_score")
+        plt.ylabel("density")
+        plt.plot(xs, tdensity(xs), color='g', label='target')
+        plt.plot(xs, ddensity(xs), color='r', label='decoy')
+        plt.legend(loc=2)
 
     plt.savefig(report_path)
 
