@@ -6,7 +6,7 @@ os.putenv("OPENBLAS_NUM_THREADS", "1")
 
 try:
     profile
-except:
+except NameError:
     profile = lambda x: x
 
 from data_handling import Experiment
@@ -51,12 +51,13 @@ class AbstractSemiSupervisedLearner(object):
         params, clf_scores = self.start_semi_supervised_learning(train)
 
         train.set_and_rerank("classifier_score", clf_scores)
+
         # semi supervised iteration:
         for inner in range(num_iter):
             params, clf_scores = self.iter_semi_supervised_learning(train)
             train.set_and_rerank("classifier_score", clf_scores)
 
-        # nach semi supervsised iter: classfiy full dataset
+        # after semi supervised iteration: classify full dataset
         clf_scores = self.score(experiment, params)
         mu, nu = mean_and_std_dev(clf_scores)
         experiment.set_and_rerank("classifier_score", clf_scores)
@@ -101,8 +102,7 @@ class StandardSemiSupervisedLearner(AbstractSemiSupervisedLearner):
     def start_semi_supervised_learning(self, train):
         fdr = CONFIG.get("semi_supervised_learner.initial_fdr")
         lambda_ = CONFIG.get("semi_supervised_learner.initial_lambda")
-        td_peaks, bt_peaks = self.select_train_peaks(
-            train, "main_score", fdr, lambda_)
+        td_peaks, bt_peaks = self.select_train_peaks(train, "main_score", fdr, lambda_)
         model = self.inner_learner.learn(td_peaks, bt_peaks, False)
         w = model.get_parameters()
         clf_scores = model.score(train, False)
@@ -113,7 +113,7 @@ class StandardSemiSupervisedLearner(AbstractSemiSupervisedLearner):
     def iter_semi_supervised_learning(self, train):
         fdr = CONFIG.get("semi_supervised_learner.iteration_fdr")
         lambda_ = CONFIG.get("semi_supervised_learner.iteration_lambda")
-        td_peaks, bt_peaks = self.select_train_peaks( train, "classifier_score", fdr, lambda_)
+        td_peaks, bt_peaks = self.select_train_peaks(train, "classifier_score", fdr, lambda_)
 
         model = self.inner_learner.learn(td_peaks, bt_peaks, True)
         w = model.get_parameters()
